==> haskell-optparse-applicative-0.14.3.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.3.0
id: optparse-applicative-0.14.3.0-73P4KsioIWfIWY4ivbT4M
key: optparse-applicative-0.14.3.0-73P4KsioIWfIWY4ivbT4M
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: c39d601ecdfbabb91c2c908fcc06836f
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-applicative-0.14.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-applicative-0.14.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/optparse-applicative-0.14.3.0
hs-libraries: HSoptparse-applicative-0.14.3.0-73P4KsioIWfIWY4ivbT4M
depends:
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ base-4.12.0.0
    process-1.6.5.0 transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-applicative-0.14.3.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-applicative
version: 0.14.3.0
id: optparse-applicative-0.14.3.0-AwM1RtrCATI1yFTHqiSLSy
key: optparse-applicative-0.14.3.0-AwM1RtrCATI1yFTHqiSLSy
license: BSD-3-Clause
copyright: (c) 2012-2017 Paolo Capriotti <paolo@capriotti.io>
maintainer: huw.campbell@gmail.com
author: Paolo Capriotti, Huw Campbell
homepage: https://github.com/pcapriotti/optparse-applicative
synopsis: Utilities and combinators for parsing command line options
description:
    optparse-applicative is a haskell library for parsing options
    on the command line, providing a powerful applicative interface
    for composing these options.
    .
    optparse-applicative takes care of reading and validating the
    arguments passed to the command line, handling and reporting
    errors, generating a usage line, a comprehensive help screen,
    and enabling context-sensitive bash completions.
    .
    See the included README for detailed instructions and examples,
    which is also available on github
    <https://github.com/pcapriotti/optparse-applicative>.
category: System, CLI, Options, Parsing
abi: 5d53e1c936d9bbf9e277046c97cfad9b
exposed: True
exposed-modules:
    Options.Applicative Options.Applicative.Arrows
    Options.Applicative.BashCompletion Options.Applicative.Builder
    Options.Applicative.Builder.Completer
    Options.Applicative.Builder.Internal Options.Applicative.Common
    Options.Applicative.Extra Options.Applicative.Help
    Options.Applicative.Help.Chunk Options.Applicative.Help.Core
    Options.Applicative.Help.Levenshtein
    Options.Applicative.Help.Pretty Options.Applicative.Help.Types
    Options.Applicative.Internal Options.Applicative.Types
import-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-applicative-0.14.3.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/optparse-applicative-0.14.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/optparse-applicative-0.14.3.0
hs-libraries: HSoptparse-applicative-0.14.3.0-AwM1RtrCATI1yFTHqiSLSy
depends:
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ base-4.12.0.0
    process-1.6.5.0 transformers-0.5.6.2
    transformers-compat-0.6.3-1NtilqZTjCV2jyq6SVF8I5
haddock-interfaces: /usr/share/doc/haskell-optparse-applicative/html/optparse-applicative.haddock
haddock-html: /usr/share/doc/haskell-optparse-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
